@@ -6,7 +6,7 @@ use warnings;
 
 use Perinci::Sub::Wrapper qw(wrap_sub);
 
-our $VERSION = '0.06'; # VERSION
+our $VERSION = '0.07'; # VERSION
 
 use Moose;
 use experimental 'smartmatch';
@@ -184,6 +184,8 @@ sub munge_file {
     my $has_put_preamble;
     my $has_put_postamble;
 
+    my $sig = " ## this line is put by " . __PACKAGE__;
+
   LINE:
     for (@content) {
         $i++;
@@ -234,7 +236,8 @@ sub munge_file {
             if ($first_sub) {
                 # this is the first sub, let's put all requires here
                 $_ = "\n$1# [Rinci::Wrap] END presub1\n$_" if $self->debug;
-                $_ = $self->_squish_code(join "", @requires) . " $_";
+                chomp;
+                $_ = $self->_squish_code(join "", @requires) . " $_" . $sig . "\n";
                 $_ = "\n$1# [Rinci::Wrap] BEGIN presub1\n$_" if $self->debug;
             }
 
@@ -261,7 +264,7 @@ sub munge_file {
                     $preamble .= $indent . '$_w_res = do {';
                 }
                 s/\n//;
-                $_ .= " " . $self->_squish_code($preamble) . "\n";
+                $_ .= " " . $self->_squish_code($preamble) . $sig . "\n";
                 $_ = "$_\n$indent# [Rinci::Wrap] END preamble\n" if $self->debug;
                 $has_put_preamble = 1;
                 next LINE;
@@ -285,7 +288,8 @@ sub munge_file {
                     $wres{$sub_name}{source}{postamble};
                 $_ = "\n$sub_indent# [Rinci::Wrap] END postamble\n$_"
                     if $self->debug;
-                $_ = $self->_squish_code($postamble) . " $_";
+                chomp;
+                $_ = $self->_squish_code($postamble) . " $_" . $sig . "\n";
                 $_ = "\n$sub_indent# [Rinci::Wrap] BEGIN postamble\n$_"
                     if $self->debug;
                 $has_put_postamble = 1;
@@ -324,7 +328,7 @@ Dist::Zilla::Plugin::Rinci::Wrap - Insert wrapper-generated code
 
 =head1 VERSION
 
-This document describes version 0.06 of Dist::Zilla::Plugin::Rinci::Wrap (from Perl distribution Dist-Zilla-Plugin-Rinci-Wrap), released on 2015-02-23.
+This document describes version 0.07 of Dist::Zilla::Plugin::Rinci::Wrap (from Perl distribution Dist-Zilla-Plugin-Rinci-Wrap), released on 2015-02-25.
 
 =head1 SYNOPSIS
 
@@ -504,7 +508,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Dist-Zilla
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Dist-Zilla-Plugin-Rinci-Wrap>.
+Source repository is at L<https://github.com/perlancar/perl-Dist-Zilla-Plugin-Rinci-Wrap>.
 
 =head1 BUGS
 
